==> htmlunit-2.47.1-sources.jar: com/gargoylesoftware/htmlunit/javascript/host/event/MouseScrollEvent.java <==
/*
 * Copyright (c) 2002-2021 Gargoyle Software Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.gargoylesoftware.htmlunit.javascript.host.event;

import static com.gargoylesoftware.htmlunit.javascript.configuration.SupportedBrowser.FF;
import static com.gargoylesoftware.htmlunit.javascript.configuration.SupportedBrowser.FF78;

import com.gargoylesoftware.htmlunit.javascript.configuration.JsxClass;
import com.gargoylesoftware.htmlunit.javascript.configuration.JsxConstant;
import com.gargoylesoftware.htmlunit.javascript.configuration.JsxConstructor;

/**
 * A JavaScript object for {@code MouseScrollEvent}.
 *
 * @author Ahmed Ashour
 * @author Ronald Brill
 */
@JsxClass({FF, FF78})
public class MouseScrollEvent extends MouseEvent {

    /** Constant for {@code HORIZONTAL_AXIS}. */
    @JsxConstant
    public static final int HORIZONTAL_AXIS = 1;

    /** Constant for {@code VERTICAL_AXIS}. */
    @JsxConstant
    public static final int VERTICAL_AXIS = 2;

    /**
     * Default constructor.
     */
    @JsxConstructor
    public MouseScrollEvent() {
    }
}

==> htmlunit-2.64.0-sources.jar: com/gargoylesoftware/htmlunit/javascript/host/event/MouseScrollEvent.java <==
/*
 * Copyright (c) 2002-2022 Gargoyle Software Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.gargoylesoftware.htmlunit.javascript.host.event;

import static com.gargoylesoftware.htmlunit.javascript.configuration.SupportedBrowser.FF;
import static com.gargoylesoftware.htmlunit.javascript.configuration.SupportedBrowser.FF_ESR;

import com.gargoylesoftware.htmlunit.javascript.configuration.JsxClass;
import com.gargoylesoftware.htmlunit.javascript.configuration.JsxConstant;
import com.gargoylesoftware.htmlunit.javascript.configuration.JsxConstructor;

/**
 * A JavaScript object for {@code MouseScrollEvent}.
 *
 * @author Ahmed Ashour
 * @author Ronald Brill
 */
@JsxClass({FF, FF_ESR})
public class MouseScrollEvent extends MouseEvent {

    /** Constant for {@code HORIZONTAL_AXIS}. */
    @JsxConstant
    public static final int HORIZONTAL_AXIS = 1;

    /** Constant for {@code VERTICAL_AXIS}. */
    @JsxConstant
    public static final int VERTICAL_AXIS = 2;

    /**
     * Default constructor.
     */
    @JsxConstructor
    public MouseScrollEvent() {
    }
}
